#!/usr/bin/env python

#############################################################################
##
## Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
## All rights reserved.
## Contact: Nokia Corporation (qt-info@nokia.com)
##
## This file is part of the documentation of Qt. It was originally
## published as part of Qt Quarterly.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial Usage
## Licensees holding valid Qt Commercial licenses may use this file in
## accordance with the Qt Commercial License Agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and Nokia.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 2.1 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL included in the
## packaging of this file.  Please review the following information to
## ensure the GNU Lesser General Public License version 2.1 requirements
## will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
##
## In addition, as a special exception, Nokia gives you certain additional
## rights.  These rights are described in the Nokia Qt LGPL Exception
## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3.0 as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL included in the
## packaging of this file.  Please review the following information to
## ensure the GNU General Public License version 3.0 requirements will be
## met: http://www.gnu.org/copyleft/gpl.html.
##
## If you have questions regarding the use of this file, please contact
## Nokia at qt-info@nokia.com.
## $QT_END_LICENSE$
##
#############################################################################

import sys

from PyQt4.QtCore import QObject, QRectF, QSizeF
from PyQt4.QtGui import QApplication, QColor, QLabel, QMessageBox, QPainter, QPixmap
from PyQt4.QtMobility.QtLocation import *

class MapLabel(QLabel):

    def __init__(self, manager):
    
        QLabel.__init__(self)
        
        pixmap = QPixmap(300, 300)
        pixmap.fill(QColor(255, 255, 255))
        self.setPixmap(pixmap)
        
        self.mapData = manager.createMapData()
        self.mapData.updateMapDisplay.connect(self.updateMap)
        
        self.mapData.setWindowSize(QSizeF(300, 300))
        self.mapData.fitInViewport(
            QGeoBoundingBox(QGeoCoordinate(37.8, -25.75),
                                       0.20598828792572021, 0.16276264821291164))
        self.mapData.setMapType(QGraphicsGeoMap.TerrainMap)
        self.mapData.setZoomLevel(10)
    
    def updateMap(self, rectangle):
    
        pixmap = QPixmap(self.pixmap())
        painter = QPainter()
        painter.begin(pixmap)
        self.mapData.paint(painter, None)
        painter.end()
        
        self.setPixmap(pixmap)


if __name__ == "__main__":

    app = QApplication(sys.argv)
    services = QGeoServiceProvider.availableServiceProviders()
    if not services:
        QMessageBox.critical(None,
            app.translate("pixmap_map", "Pixmap Map"),
            app.translate("pixmap_map",
                          "Failed to find any map services. Please ensure that "
                          "the location services plugins for Qt Mobility have "
                          "been built and, if necessary, set the QT_PLUGIN_PATH "
                          "environment variable to the location of the Qt Mobility "
                          "plugins directory."))
        sys.exit(1)
    
    service = QGeoServiceProvider("nokia")
    if service.error() != service.NoError:
        QMessageBox.critical(None,
            app.translate("pixmap_map", "Pixmap Map"),
            app.translate("pixmap_map",
                          "The service failed with the following error:\n"
                          "%1").arg(service.errorString()))
        sys.exit(1)
    
    manager = service.mappingManager()
    
    label = MapLabel(manager)
    label.show()
    
    sys.exit(app.exec_())
